@@ -255,10 +255,43 @@ class TestVariogramArguments(unittest.TestCase):
         self.assertIsNone(V.cov)
         self.assertIsNone(V.cof)
 
-    def test_binning_non_string_arg(self):
-        V = Variogram(self.c, self.v, n_lags=8)
+    def test_binning_callable_arg(self):
 
-        return True
+        # define a custom function similar an existing string function
+        def even_func(distances, n, maxlag):
+            return np.linspace(0, np.min(np.nanmax(distances), maxlag), n + 1)[1:], None
+
+        # run custom function and string function
+        V = Variogram(self.c, self.v, n_lags=8, bin_func=even_func)
+        V2 = Variogram(self.c, self.v, n_lags=8, bin_func='even')
+
+        # check the binning is indeed the same
+        assert np.array_equal(V.bins, V2.bins)
+
+    def test_binning_iterable_arg(self):
+
+        # define a custom iterable with bin edges
+        custom_bins = np.linspace(5,50,5)
+
+        # check that the bins are set according to those edges
+        V = Variogram(self.c, self.v, bin_func=custom_bins)
+
+        assert np.array_equal(V.bins, custom_bins)
+        assert V.n_lags == len(custom_bins)
+        assert V.maxlag == max(custom_bins)
+
+        # check that custom bins have priority over nlags and maxlag
+        V = Variogram(self.c, self.v, bin_func=custom_bins, nlags=1000)
+
+        assert np.array_equal(V.bins, custom_bins)
+        assert V.n_lags == len(custom_bins)
+        assert V.maxlag == max(custom_bins)
+
+        V = Variogram(self.c, self.v, bin_func=custom_bins, maxlag=1000)
+
+        assert np.array_equal(V.bins, custom_bins)
+        assert V.n_lags == len(custom_bins)
+        assert V.maxlag == max(custom_bins)
 
     def test_binning_kmeans_method(self):
         V = Variogram(
@@ -527,6 +560,31 @@ class TestVariogramArguments(unittest.TestCase):
 
             self.assertTrue('read-only' in str(e.exception))
 
+    def test_get_bin_count(self):
+
+        V = Variogram(self.c, self.v)
+
+        # check type
+        assert isinstance(V.bin_count, np.ndarray)
+
+        # check against real bin count
+        assert np.array_equal(V.bin_count, np.array([22, 54, 87, 65, 77, 47, 46, 24, 10,  2]))
+
+        # check property gets updated
+        old_bin_count = V.bin_count
+
+        # when setting binning function
+        V.bin_func = 'uniform'
+        assert not np.array_equal(V.bin_count, old_bin_count)
+
+        # when setting maxlag
+        old_bin_count = V.bin_count
+        V.maxlag = 25
+        assert not np.array_equal(V.bin_count, old_bin_count)
+
+        # when setting nlags
+        V.n_lags = 5
+        assert len(V.bin_count) == 5
 
 class TestVariogramFittingProcedure(unittest.TestCase):
     def setUp(self):
@@ -558,9 +616,8 @@ class TestVariogramFittingProcedure(unittest.TestCase):
         with self.assertRaises(AttributeError) as e:
             self.V.fit_sigma
         
-        self.assertEqual(
-            str(e.exception),
-            'fit_sigma and bins need the same length.'
+        self.assertTrue(
+            'len(fit_sigma)' in str(e.exception)
         )
 
     def test_fit_sigma_raises_ValueError(self):
@@ -669,7 +726,7 @@ class TestVariogramFittingProcedure(unittest.TestCase):
         )
 
     def test_fitted_model(self):
-        self.V.fit_method = 'trf'
+        self.V._fit_method = 'trf'
         self.V.fit_sigma = None
         fun = self.V.fitted_model
 
@@ -681,16 +738,16 @@ class TestVariogramFittingProcedure(unittest.TestCase):
         )
 
     def test_unavailable_method(self):
-        with self.assertRaises(ValueError) as e:
+        with self.assertRaises(AttributeError) as e:
             self.V.fit(method='unsupported')
 
         self.assertTrue(
-            "fit method has to be one of" in str(e.exception)
+            "fit_method has to be one of" in str(e.exception)
         )
 
     def test_implicit_run_fit_fitted_model(self):
         self.V.fit_sigma = None
-        self.V.fit_method = 'trf'
+        self.V._fit_method = 'trf'
         result = np.array([12.48, 17.2, 17.2, 17.2])
 
         # remove cof
@@ -705,7 +762,7 @@ class TestVariogramFittingProcedure(unittest.TestCase):
 
     def test_implicit_run_fit_transform(self):
         self.V.fit_sigma = None
-        self.V.fit_method = 'trf'
+        self.V._fit_method = 'trf'
         result = np.array([12.48, 17.2, 17.2, 17.2])
 
         # test on transform
@@ -780,7 +837,7 @@ class TestVariogramFittingProcedure(unittest.TestCase):
         )
 
         # switch to manual fit
-        V.fit_method = 'manual'
+        V._fit_method = 'manual'
         V.fit(range=10, sill=5, shape=3)
 
         self.assertEqual(V.parameters, [10., 5., 3., 0.0])
@@ -795,7 +852,7 @@ class TestVariogramFittingProcedure(unittest.TestCase):
         params = V.parameters
 
         # switch fit method
-        V.fit_method = 'manual'
+        V._fit_method = 'manual'
         V.fit(sill=14)
 
         # expected output
@@ -808,7 +865,7 @@ class TestVariogramFittingProcedure(unittest.TestCase):
         )      
 
 
-class TestVariogramQaulityMeasures(unittest.TestCase):
+class TestVariogramQualityMeasures(unittest.TestCase):
     def setUp(self):
         # set up default values, whenever c and v are not important
         np.random.seed(42)
